/****************************************************************************
 Copyright (c) 2017-2018 Xiamen Yaji Software Co., Ltd.
 
 http://www.cocos2d-x.org
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
 to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:
 
 The above copyright notice and this permission notice shall be included in
 all copies or substantial portions of the Software.
 
 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 THE SOFTWARE.
 ****************************************************************************/

#include "HelloWorldScene.h"

USING_NS_CC;

Scene* HelloWorld::createScene()
{
    return HelloWorld::create();
}

// Print useful error message instead of segfaulting when files are not there.
static void problemLoading(const char* filename)
{
    printf("Error while loading: %s\n", filename);
    printf("Depending on how you compiled you might have to add 'Resources/' in front of filenames in HelloWorldScene.cpp\n");
}

// on "init" you need to initialize your instance
bool HelloWorld::init()
{
    //////////////////////////////
    // 1. super init first
    if ( !Scene::init() )
    {
        return false;
    }

    auto visibleSize = Director::getInstance()->getVisibleSize();
    Vec2 origin = Director::getInstance()->getVisibleOrigin();
    float x = origin.x + visibleSize.width / 2;
    float y = origin.y + visibleSize.height / 2;

    auto spriteCache = SpriteFrameCache::getInstance();
    spriteCache->addSpriteFramesWithFile("numbers.plist");
    
    Vector<SpriteFrame*> frames;
    frames.pushBack(spriteCache->getSpriteFrameByName("number0.png"));
    frames.pushBack(spriteCache->getSpriteFrameByName("number1.png"));
    frames.pushBack(spriteCache->getSpriteFrameByName("number2.png"));
    frames.pushBack(spriteCache->getSpriteFrameByName("number3.png"));
    frames.pushBack(spriteCache->getSpriteFrameByName("number4.png"));
    frames.pushBack(spriteCache->getSpriteFrameByName("number5.png"));
    frames.pushBack(spriteCache->getSpriteFrameByName("number6.png"));
    frames.pushBack(spriteCache->getSpriteFrameByName("number7.png"));
    frames.pushBack(spriteCache->getSpriteFrameByName("number8.png"));
    frames.pushBack(spriteCache->getSpriteFrameByName("number9.png"));
    auto animation = Animation::createWithSpriteFrames(frames);
    animation->setDelayPerUnit(0.2);
    animation->setLoops(-1);

    auto action = Animate::create(animation);
    
    auto sprite = Sprite::createWithSpriteFrame(frames.front());
    // or just:
    // auto sprite = Sprite::create();
    sprite->setPosition(x, y);
    sprite->runAction(action);
    
    this->addChild(sprite, 0, 1);
    //this->scheduleUpdate();
    
    return true;
}

void HelloWorld::update(float delta)
{
    auto sprite = this->getChildByTag(1);
    auto position = sprite->getPosition();
    position.x += (20 * delta);
    sprite->setPosition(position);
}

void HelloWorld::menuCloseCallback(Ref* pSender)
{
    //Close the cocos2d-x game scene and quit the application
    Director::getInstance()->end();

    /*To navigate back to native iOS screen(if present) without quitting the application  ,do not use Director::getInstance()->end() as given above,instead trigger a custom event created in RootViewController.mm as below*/

    //EventCustom customEndEvent("game_scene_close_event");
    //_eventDispatcher->dispatchEvent(&customEndEvent);


}
